@@ -72,6 +72,7 @@ func TestExec(t *testing.T) {
 	testEasygen(t, "list1", "list1")
 	testEasygen(t, "listfunc1", "listfunc1")
 	testEasygen(t, "listfunc2", "listfunc2")
+	testEasygen(t, "tf-calc", "tf-calc")
 
 	//Test Basic Json Functions
 	testEasygen(t, "list0j", "list0j")
@@ -84,6 +85,9 @@ func TestExec(t *testing.T) {
 	//Test HTML
 	testEasygen(t, "list1HTML", "list1HTML", "list1")
 
+	//Test lowercase keys
+	testEasygen(t, "example-lowercase", "example-lowercase")
+
 	// varcaser string functions
 	testEasygen(t, "var0", "-ts", "{{.Name}}", "var0")
 	testEasygen(t, "var1", "-ts", "{{clk2uc .Name}}", "var0")
@@ -104,6 +108,11 @@ func TestExec(t *testing.T) {
 	testEasygen(t, "enum_multiple_template_files", "enum_c-header,enum_c-source", "raid_type.yaml")
 	testEasygen(t, "enum_multiple_template_and_data", "enum_c-header,enum_c-to_str", "raid_type", "raid_driver.yaml")
 
+	// Test with multiple data inputs files:
+	testEasygen(t, "lists", "lists", "list0.yaml,listfunc2.yaml")
+	testEasygen(t, "lists", "lists", "list0,listfunc2")
+	testEasygen(t, "lists", "lists", "listfunc2.yaml,list0.yaml")
+
 	//Test nested templates
 	//testEasygen(t, "nested_header_footer", "nested_header.tmpl,nested_footer.tmpl,nested_thanks.tmpl", "nested_data.yaml")
 	testEasygen(t, "nested_demo_argsa", "nested_demo_argsa", "nested_data.yaml")
