@@ -15,19 +15,19 @@ func ExampleExecute0() {
 
 	tmpl := easygen.NewTemplate().Funcs(easygen.FuncDefs())
 
-	// define driving data of any type
-	v0 := "some-init-method"
+	// define driving data
+	v0 := easygen.EgData{"v": "some-init-method"}
 	// https://godoc.org/github.com/go-easygen/easygen#Execute0
 	// provide template string, not file name
-	easygen.Execute0(tmpl, os.Stdout, "{{stringsToUpper .}}\n", v0)
+	easygen.Execute0(tmpl, os.Stdout, "{{stringsToUpper .v}}\n", v0)
 
-	// Demo of using driving data of pure slice/array
-	v1 := []string{"red", "blue", "white"}
-	easygen.Execute0(tmpl, os.Stdout, "The colors are: {{range .}}{{.}}, {{end}}.\n", v1)
+	// Demo of using driving data of slice/array
+	v1 := easygen.EgData{"v": []string{"red", "blue", "white"}}
+	easygen.Execute0(tmpl, os.Stdout, "The colors are: {{range .v}}{{.}}, {{end}}.\n", v1)
 
 	// Demo output to string
 	var b strings.Builder
-	easygen.Execute0(tmpl, &b, "The colors are: {{range $i, $color := .}}{{$color}}{{if lt $i ($ | len | minus1)}}, {{end}}{{end}}.\n", v1)
+	easygen.Execute0(tmpl, &b, "The colors are: {{range $i, $color := .v}}{{$color}}{{if lt $i ($.v | len | minus1)}}, {{end}}{{end}}.\n", v1)
 	fmt.Print(b.String())
 
 	// Output:
