@@ -156,8 +156,8 @@ var egFuncMap = FuncMap{
 	"stringsTrimSpace":      strings.TrimSpace,
 	"stringsTrimSuffix":     strings.TrimSuffix,
 	// aliases
-	"eqf":   strings.EqualFold,
-	"split": strings.Fields,
+	"eqf":     strings.EqualFold,
+	"split":   strings.Fields,
 	"sprintf": fmt.Sprintf,
 
 	// == standard regexp function definitions
@@ -178,12 +178,16 @@ var egFuncMap = FuncMap{
 	// == my added functions
 	"ENV":         os.Getenv,
 	"substr":      Substr,
+	"indent":      Indent,
+	"pindent":     PIndent,
 	"coalesce":    Coalesce,
 	"quote4shell": Quote4shell,
 
 	"iterate":   Iterate,
 	"argsa":     ArgsA,
 	"argsm":     ArgsM,
+	"add":       Add,
+	"minus":     Minus,
 	"minus1":    Minus1,
 	"date":      Date,
 	"timestamp": Timestamp,
